@@ -12,7 +12,7 @@ def openWindowsFolder(folder: str):
     os.system(f"start explorer {folder}")
 
 
-def getPath(basePath: str, *parList: str) -> str:
+def getPath(basePath: str = "", *parList: str):
     return os.path.abspath(os.path.join(basePath, *parList))
 
 
