@@ -2,10 +2,12 @@ import asyncio
 import binascii
 import hashlib
 import os
+from functools import wraps
 from typing import Any, Awaitable, Optional
 
 import aiofiles
 import aiohttp
+from async_timeout import timeout
 
 from beniutils.http import getHeaderByDefault
 
@@ -193,6 +195,16 @@ async def asyncDownload(url: str, file: str):
     await asyncWriteBinFile(file, result)
 
 
+def asyncWait(waitSeconds: float):
+    def _log(func: Any):
+        @wraps(func)
+        async def wrapper(*args: Any, **kwargs: Any):
+            with timeout(waitSeconds):
+                return await func(*args, **kwargs)
+        return wrapper
+    return _log
+
+
 # 两个方案都能解决问题
 # asyncio.run(runAsync())
 # =>
